﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Persist.Model;
using Persist.Services;
using System.Collections;

namespace Business.Controller
{
    public class RoomController
    {
        RoomServices RoomServices;
        ReserveController ReserveController;

        public RoomController()
        {
            this.RoomServices = new RoomServices();
            this.ReserveController = new ReserveController();
        }

        public bool Create(Room room)
        {
            bool status = false;

            try
            {
                RoomServices.Create(room);
                status = true;
            }
            catch
            {
            }

            return status;
        }

        public bool Update(Room room)
        {
            bool status = false;

            try
            {
                Room result = Find(room.RoomID);

                if (result != null)
                {
                    RoomServices.Update(room);
                    status = true;
                }
            }
            catch
            {
            }

            return status;
        }

        public bool Delete(int roomID)
        {
            bool status = false;

            try
            {
                status = DeleteReserves(roomID);

                if (!status)
                    throw new Exception();

                status = false;
                RoomServices.RefreshContext();

                Room result = Find(roomID);

                if (result != null)
                {
                    RoomServices.Delete(roomID);
                    status = true;
                }
            }
            catch
            {
            }

            return status;
        }

        public bool DeleteReserves(int roomID)
        {
            bool status = true;

            try
            {
                foreach (Reserve item in RoomServices.GetReserves(roomID))
                {
                    status = ReserveController.Delete(item.ReserveID);
                    if (!status)
                        break;
                }
            }
            catch
            {
                status = false;
            }

            return status;
        }

        public Room Find(int roomID)
        {
            Room result = null;

            try
            {
                result = RoomServices.Find(roomID);
            }
            catch
            {
            }

            return result;
        }

        public List<Room> FindAll()
        {
            List<Room> results = null;

            try
            {
                results = RoomServices.FindAll();
            }
            catch
            {
            }

            return results;
        }

        //گزارش 1
        //لیستی از اتاق ها به همراه اطلاعات کامل
        public ICollection ReportOfRoomsWithInformationComplete()
        {
            ICollection result = null;

            try
            {
                result = RoomServices.ReportOfRoomsWithInformationComplete();
            }
            catch
            {
            }

            return result;
        }

        //گزارش 2
        //لیست اتاق های  خالی از تاریخ فلان تا تاریخ فلان
        public ICollection ReportOfEmptyRoom(DateTime startDate, DateTime toDate)
        {
            List<EmptyRoom> emptyRooms = new List<EmptyRoom>();
            int counter = 0;

            foreach (Room room in FindAll())
            {
                emptyRooms.Add(new EmptyRoom()
                {
                    CountBedroom = room.CountBedroom,
                    Description = room.Description,
                    Price = room.Price,
                    RoomID = room.RoomID,
                    RoomNumber = room.RoomNumber
                });

                for (DateTime i = startDate; i <= toDate; i = i.AddDays(1))
                {
                    //آیا در تاریخ مذکور این اتاق رزرو شده است
                    ICollection resultTemp = RoomServices.ReportOfFullRoom(i, room.RoomID);

                    //اگر این متغیر تعداد رکورد برگشتیش صفر باشد یعنی اتاق در این بازه تاریخی رزرو نشده است یا خالی است
                    if (resultTemp.Count == 0)
                    {
                        //اتاق جاری در این تاریخ خالی می باشد
                        emptyRooms[counter].DateEmpty.Add(i);
                    }
                }
                counter++;
            }

            return emptyRooms;
        }

        //گزارش 3
        //لیست اتاق های ایکس خوابه
        public List<Room> ReportOfXBedroomRoom(int x)
        {
            List<Room> rooms = null;

            try
            {
                rooms = RoomServices.ReportOfXBedroomRoom(x);
            }
            catch
            {
            }

            return rooms;
        }

        //گزارش 4
        //لیست اتاق هایی با رنج قیمت خاص
        public List<Room> ReportOfPriceRoom(double xPrice, double yPrice)
        {
            List<Room> rooms = null;

            try
            {
                rooms = RoomServices.ReportOfPriceRoom(xPrice, yPrice);
            }
            catch
            {
            }

            return rooms;
        }

        //گزارش 5
        //لیست اتاق های ایکس خوابه با رنج قیمت خاص
        public List<Room> ReportOfPriceAndXBedroom(double xPrice, double yPrice, int x)
        {
            List<Room> rooms = null;

            try
            {
                rooms = RoomServices.ReportOfPriceAndXBedroom(xPrice, yPrice, x);
            }
            catch
            {
            }

            return rooms;
        }

        //گزارش 6
        //لیست اتاق ایکس خوابه رزرو نشده در بازه تاریخ فلان 
        public ICollection ReportOfEmptyXBedroom(DateTime startDate, DateTime toDate, int x)
        {
            List<EmptyRoom> emptyRooms = new List<EmptyRoom>();
            int counter = 0;

            foreach (Room room in FindAll())
            {
                if (room.CountBedroom == x)
                {
                    emptyRooms.Add(new EmptyRoom()
                    {
                        CountBedroom = room.CountBedroom,
                        Description = room.Description,
                        Price = room.Price,
                        RoomID = room.RoomID,
                        RoomNumber = room.RoomNumber
                    });

                    for (DateTime i = startDate; i <= toDate; i = i.AddDays(1))
                    {

                        ICollection resultTemp = RoomServices.ReportOfFullXBedroom(i, room.RoomID, x);

                        //اگر این متغیر تعداد رکورد برگشتیش صفر باشد یعنی اتاق در این بازه تاریخی رزرو نشده است یا خالی است
                        if (resultTemp.Count == 0)
                        {
                            emptyRooms[counter].DateEmpty.Add(i);
                        }
                    }
                    counter++;
                }
            }

            return emptyRooms;
        }

        //گزارش 7
        //لیست اتاق ایکس خوابه در رنج قیمت خاص پر در تاریخ فلان 
        public ICollection ReportOfFullXBedroomAndRangePrice(DateTime startDate, DateTime toDate, int x, double xPrice, double yPrice)
        {
            List<EmptyRoom> emptyRooms = new List<EmptyRoom>();
            int counter = 0;

            foreach (Room room in FindAll())
            {
                if (room.CountBedroom == x && room.Price >= xPrice && room.Price <= yPrice)
                {
                    emptyRooms.Add(new EmptyRoom()
                    {
                        CountBedroom = room.CountBedroom,
                        Description = room.Description,
                        Price = room.Price,
                        RoomID = room.RoomID,
                        RoomNumber = room.RoomNumber
                    });

                    for (DateTime i = startDate; i <= toDate; i = i.AddDays(1))
                    {

                        ICollection resultTemp = RoomServices.ReportOfFullXBedroomAndRangePrice(i, room.RoomID, x, xPrice, yPrice);

                        //اگر این متغیر تعداد رکورد برگشتیش صفر باشد یعنی اتاق در این بازه تاریخی رزرو نشده است یا خالی است
                        if (resultTemp.Count == 0)
                        {
                            emptyRooms[counter].DateEmpty.Add(i);
                        }
                    }
                    counter++;
                }
            }

            return emptyRooms;
        }

        public List<Reserve> GetReserves(int roomID)
        {
            List<Reserve> results = null;

            try
            {
                results = RoomServices.GetReserves(roomID);
            }
            catch
            {
            }

            return results;
        }
    }
}