﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Persist.Model;
using System.Collections;

namespace Persist.Services
{
    public class ReserveServices
    {
        HotelSiteEntities Context;

        public ReserveServices()
        {
            this.Context = new HotelSiteEntities();
        }

        public void Create(Reserve reserve)
        {
            Context.Reserves.AddObject(reserve);
            Context.SaveChanges();
        }

        public void Update(Reserve reserve)
        {
            Reserve result = Find(reserve.ReserveID);

            result.Person_ID = reserve.Person_ID;
            result.Room_ID = reserve.Room_ID;
            result.PriceSum = reserve.PriceSum;
            result.EndDate = reserve.EndDate;
            result.StartDate = reserve.StartDate;

            Context.SaveChanges();
        }

        public void Delete(int reserveID)
        {
            Reserve result = Find(reserveID);

            Context.Reserves.DeleteObject(result);
            Context.SaveChanges();
        }

        public Reserve Find(int reserveID)
        {
            Reserve result = Context.Reserves.Where(r => r.ReserveID == reserveID).SingleOrDefault();
            return result;
        }

        public List<Reserve> FindAll()
        {
            List<Reserve> results = Context.Reserves.Select(r => r).ToList();
            return results;
        }

        public ICollection SelectWithParent()
        {
            ICollection results = Context.Reserves.Select(r => new
            {
                r.ReserveID,
                r.PriceSum,
                r.EndDate,
                r.StartDate,
                Person_UserName = r.Person.UserName,
                Room_RoomNumber = r.Room.RoomNumber,
            }).ToList();
            return results;
        }

        public List<Reserve> GetReserveBetweenDateTime(DateTime startDate, DateTime endDate, int roomId)
        {
            List<Reserve> reserves = Context.Reserves.Where(r => ((r.StartDate.Year * 365 + r.StartDate.Month * 31 + r.StartDate.Day <= startDate.Year * 365 + startDate.Month * 31 + startDate.Day &&
                                                             r.EndDate.Year * 365 + r.EndDate.Month * 31 + r.EndDate.Day >= startDate.Year * 365 + startDate.Month * 31 + startDate.Day) ||
                                                              (r.StartDate.Year * 365 + r.StartDate.Month * 31 + r.StartDate.Day <= endDate.Year * 365 + endDate.Month * 31 + endDate.Day &&
                                                             r.EndDate.Year * 365 + r.EndDate.Month * 31 + r.EndDate.Day >= endDate.Year * 365 + endDate.Month * 31 + endDate.Day))
                                                             && r.Room_ID == roomId).ToList();
            return reserves;
        }

        public double GetPriceReserve(int roomID)
        {
            double price = Context.Rooms.Where(r => r.RoomID == roomID).Select(r => r.Price).SingleOrDefault();
            return price;
        }

        public void RefreshContext()
        {
            Context = new HotelSiteEntities();
        }
    }
}