﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;
namespace Presentation.Pages.Admin
{
    public partial class ManageHotel : System.Web.UI.Page
    {
        Business.Controller.HotelController HotelController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;
        Business.Controller.PersonController PersonController;

        public ManageHotel()
        {
            this.HotelController = new Business.Controller.HotelController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
            PersonController = new Business.Controller.PersonController();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");

            BindGridView();
        }

        protected void grdHotel_RowDeleting(object sender, GridViewDeleteEventArgs e)
        {
            BindGridView();
        }

        protected void grdHotel_RowEditing(object sender, GridViewEditEventArgs e)
        {
            BindGridView();
        }

        protected void grdHotel_RowUpdating(object sender, GridViewUpdateEventArgs e)
        {
            BindGridView();
        }

        protected void grdHotel_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            ViewState["HotelID"] = e.CommandArgument.ToString();
            int hotelID = Convert.ToInt32(e.CommandArgument.ToString());
            switch (e.CommandName.ToString())
            {
                case "doEdit":
                    {
                        ResetHotel();
                        ViewState["Mode"] = "doEdit";
                        LoadHotel(hotelID);
                        mvHotel.SetActiveView(vwInsertUpdateHotel);
                        break;
                    }
                case "doDelete":
                    {
                        this.HotelController.Delete(hotelID);
                        BindGridView();
                        break;
                    }
            }
        }

        protected void grdHotel_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            grdHotel.PageIndex = e.NewPageIndex;
            BindGridView();
        }

        private void BindGridView()
        {
            this.grdHotel.DataSource = HotelController.FindAll();
            this.grdHotel.DataBind();
        }

        private void ResetHotel()
        {
            txtDescription.Text = string.Empty;
            txtImage.Text = string.Empty;
            txtAddress.Text = string.Empty;
            txtHotelName.Text = string.Empty;
            txtEmail.Text = string.Empty;
            txtTelephone.Text = string.Empty;
        }

        private void LoadHotel(int hotelID)
        {
            Persist.Model.Hotel hotel = this.HotelController.Find(hotelID);
            if (hotel != null)
            {
                txtDescription.Text = hotel.Description.ToString();
                txtImage.Text = hotel.Image.ToString();
                txtAddress.Text = hotel.Address.ToString();
                txtHotelName.Text = hotel.HotelName.ToString();
                txtEmail.Text = hotel.Email.ToString();
                txtTelephone.Text = hotel.Telephone.ToString();
            }
        }

        private bool CreateHotel()
        {
            bool status = HotelController.Create(new Persist.Model.Hotel()
            {
                Description = Convert.ToString(txtDescription.Text),
                Image = Convert.ToString(txtImage.Text),
                Address = Convert.ToString(txtAddress.Text),
                HotelName = Convert.ToString(txtHotelName.Text),
                Email = Convert.ToString(txtEmail.Text),
                Telephone = Convert.ToString(txtTelephone.Text)
            });
            return status;
        }

        private bool UpdateHotel(int hotelID)
        {
            bool status = HotelController.Update(new Persist.Model.Hotel()
            {
                HotelID = hotelID,
                Description = Convert.ToString(txtDescription.Text),
                Image = Convert.ToString(txtImage.Text),
                Address = Convert.ToString(txtAddress.Text),
                HotelName = Convert.ToString(txtHotelName.Text),
                Email = Convert.ToString(txtEmail.Text),
                Telephone = Convert.ToString(txtTelephone.Text)
            });
            return status;
        }

        protected void btnCancelHotel_Click(object sender, EventArgs e)
        {
            mvHotel.SetActiveView(vwManagementHotel);
        }

        protected void btnInsertHotel_Click(object sender, EventArgs e)
        {
            ViewState["Mode"] = "Insert";
            ResetHotel();
            mvHotel.SetActiveView(vwInsertUpdateHotel);
        }

        protected void btnInsertAndUpdateHotel_Click(object sender, EventArgs e)
        {
            bool status;
            if (ViewState["Mode"].ToString().ToLower() == "insert")
            {
                status = CreateHotel();
            }
            else
            {
                status = UpdateHotel(Convert.ToInt32(ViewState["HotelID"].ToString()));
            }
            if (status)
            {
                BindGridView();
                mvHotel.SetActiveView(vwManagementHotel);
            }
        }

        protected void btnReturnToPanelHotel_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Pages/Admin/Default.aspx");
        }
    }
}