﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.IO;
namespace Presentation.Pages.Admin
{
    public partial class ManageRoom : System.Web.UI.Page
    {
        Business.Controller.RoomController RoomController;
        Business.Classes.DateTimeBusiness DateTimeBusiness;
        Business.Controller.PersonController PersonController;

        public ManageRoom()
        {
            this.RoomController = new Business.Controller.RoomController();
            this.DateTimeBusiness = new Business.Classes.DateTimeBusiness();
            PersonController = new Business.Controller.PersonController();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!PersonController.IsPermissionToPage(HttpContext.Current.User.Identity.Name, this.Title))
                Response.Redirect("~/Pages/Forbidden.aspx");

            BindGridView();
        }

        protected void grdRoom_RowDeleting(object sender, GridViewDeleteEventArgs e)
        {
            BindGridView();
        }

        protected void grdRoom_RowEditing(object sender, GridViewEditEventArgs e)
        {
            BindGridView();
        }

        protected void grdRoom_RowUpdating(object sender, GridViewUpdateEventArgs e)
        {
            BindGridView();
        }

        protected void grdRoom_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            ViewState["RoomID"] = e.CommandArgument.ToString();
            int roomID = Convert.ToInt32(e.CommandArgument.ToString());
            switch (e.CommandName.ToString())
            {
                case "doEdit":
                    {
                        ResetRoom();
                        ViewState["Mode"] = "doEdit";
                        LoadRoom(roomID);
                        mvRoom.SetActiveView(vwInsertUpdateRoom);
                        break;
                    }
                case "doDelete":
                    {
                        this.RoomController.Delete(roomID);
                        BindGridView();
                        break;
                    }
            }
        }

        protected void grdRoom_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            grdRoom.PageIndex = e.NewPageIndex;
            BindGridView();
        }

        private void BindGridView()
        {
            this.grdRoom.DataSource = RoomController.FindAll();
            this.grdRoom.DataBind();
        }

        private void ResetRoom()
        {
            txtDescription.Text = string.Empty;
            txtRoomNumber.Text = string.Empty;
            txtPrice.Text = string.Empty;
            txtCountBedroom.Text = string.Empty;
        }

        private void LoadRoom(int roomID)
        {
            Persist.Model.Room room = this.RoomController.Find(roomID);
            if (room != null)
            {
                txtDescription.Text = room.Description.ToString();
                txtRoomNumber.Text = room.RoomNumber.ToString();
                txtPrice.Text = room.Price.ToString();
                txtCountBedroom.Text = room.CountBedroom.ToString();
            }
        }

        private bool CreateRoom()
        {
            bool status = RoomController.Create(new Persist.Model.Room()
            {
                Description = txtDescription.Text,
                RoomNumber = Convert.ToInt32(txtRoomNumber.Text),
                Price = Convert.ToDouble(txtPrice.Text),
                CountBedroom = Convert.ToInt32(txtCountBedroom.Text)
            });
            return status;
        }

        private bool UpdateRoom(int roomID)
        {
            bool status = RoomController.Update(new Persist.Model.Room()
            {
                RoomID = roomID,
                Description = txtDescription.Text,
                RoomNumber = Convert.ToInt32(txtRoomNumber.Text),
                Price = Convert.ToDouble(txtPrice.Text),
                CountBedroom = Convert.ToInt32(txtCountBedroom.Text)
            });
            return status;
        }

        protected void btnCancelRoom_Click(object sender, EventArgs e)
        {
            mvRoom.SetActiveView(vwManagementRoom);
        }

        protected void btnInsertRoom_Click(object sender, EventArgs e)
        {
            ViewState["Mode"] = "Insert";
            ResetRoom();
            mvRoom.SetActiveView(vwInsertUpdateRoom);
        }

        protected void btnInsertAndUpdateRoom_Click(object sender, EventArgs e)
        {
            bool status;
            if (ViewState["Mode"].ToString().ToLower() == "insert")
            {
                status = CreateRoom();
            }
            else
            {
                status = UpdateRoom(Convert.ToInt32(ViewState["RoomID"].ToString()));
            }
            if (status)
            {
                BindGridView();
                mvRoom.SetActiveView(vwManagementRoom);
            }
        }

        protected void btnReturnToPanelRoom_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Pages/Admin/Default.aspx");
        }
    }
}